/*
 * Custom Configuration Files
 *
 * This table allows the user to edit configuration files.
 *
 * Nyquist Web Interface use:
 *
 * 1. Execute: sudo /usr/local/bin/custom-config -g <custom_config.id>
 * 2. Load file specified by custom_config.filename_tmp into web interface edit window, allowing user to edit content.
 * 3. If user presses "Save and Implement Later", write contents to file specified by custom_config.filename_tmp,
 *    then execute: sudo /usr/local/bin/custom-config -s <custom_config.id>
 * 4. If user presses "Save and Implement Now", write contents to file specified by custom_config.filename_tmp,
 *    then execute: sudo /usr/local/bin/custom-config -i <custom_config.id>
 *
 * custom_config
 * .filename_loc  - Where the file resides, and where edited content shall be saved, e.g. /etc/snmp/snmpd.oonf
 * .filename_tmp  - Where shall the web interface editable file be saved, e.g. /tmp/snmpd.conf
 * .pre_cmd       - Commands to run before providing file for editing (if any), e.g. systemctl stop snmpd
 * .implement_cmd - Commands to run to implement (or enable) the new configuration, e.g. "systemctl restart snmpd"
 * .instructions  - Instructions to dispaly to user (if any)
 *
 */
DROP TABLE IF EXISTS `custom_config`;

CREATE TABLE `custom_config` (
	`id`		int(11) unsigned NOT NULL AUTO_INCREMENT,
	`name`		varchar(40) NOT NULL,
	`filename_save`	varchar(255) NOT NULL,
	`filename_tmp`	varchar(255) NOT NULL,
	`chown_param`	varchar(64) NOT NULL,
	`chmod_param`	varchar(16) NOT NULL,
	`pre_cmd`	varchar(255) NOT NULL DEFAULT '',
	`implement_cmd`	varchar(255) NOT NULL,
	`description`	varchar(255) NOT NULL,
	`manual`	varchar(255) NOT NULL DEFAULT '',
	`instructions`	varchar(4095) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

INSERT INTO `custom_config` (`name`,`filename_save`,`filename_tmp`,`chown_param`,`chmod_param`,`pre_cmd`,`implement_cmd`,`description`,`manual`,`instructions`)
VALUES	('Actions and Custom Variables','/var/opt/nyquist/custom_config.conf','/tmp/custom_config.conf','www-data:www-data','0660','','/usr/local/bin/custom-config -v','Custom Nyquist System and Debian Linux variables that can be added/edited to meet your requirements.','/usr/bin/sudo /usr/local/bin/custom-config -g 1 >/dev/null 2>&1;/bin/mv /tmp/custom_config.conf /tmp/cc.conf;/bin/cat /tmp/cc.conf;rm /tmp/cc.conf','1. Determine which custom variables you need to add or edit, possibly by consulting with Bogen Technical Support. 2. After you press edit for the first time, copy the content of the displayed configuration and save it to a file on your PC that can be used as a backup of the original settings.  3. Add/Edit custom variables to meet your needs. 4. Save your changes.'),
	('SNMP Configuration','/etc/snmp/snmpd.conf','/tmp/snmpd.conf','root:root','0600','','/bin/systemctl restart snmpd','Simple Network Management Protocol (SNMP) Configuration','/usr/bin/man --nh --nj snmpd.conf','1. After you press edit for the first time, copy the content of the displayed configuration and save it to a file on your PC that can be used as a backup of the original settings. 2. Change network access permissions to meet your requirements. 3. Change community strings to meet your access requirements. 4. Enable traps to meet your requirements. 5. Save your changes. WARNING: Aggressive use of SNMP on the Nyquist system may negatively impact Nyquist server performance.'),
	('Syslog Configuration','/etc/rsyslog.conf','/tmp/rsyslog.conf','root:root','0644','','/bin/systemctl restart rsyslog','System log Configuration, allowing you to configure sending system log entries to remote computers that manage syslogs from remote devices.','/usr/bin/man --nh --nj rsyslog.conf','1. After you press edit for the first time, copy the content of the displayed configuration and save it to a file on your PC that can be used as a backup of the original settings. 2. Change settings to meet your requirements. 3. Save your changes. WARNING: You should only edit this configuration file if you understand the use and configuration of syslog and you fully understand what you are doing.');
