/*
 *
 * Dashboard Messages
 *
 * dashboard_msg
 *	.type		Type of Message (911-popup,motd,popup,text)
 *			    '911-popup'  - Display .text in POPUP message
 *			    'motd'   - Display .text in MOTD section
 *			    'text'   - Display .text in MESSAGE section
 *			    'popup'  - Display .text in POPUP message
 *	.text		Text for message (Web UI shall support auto-wrap)
 *	.action		Action button for popup messages (optional):
 *			    'Call'   - Include "Call" button
 *                          'Delete' - Allow user to delete this msg via UI
 *			    'Hangup' - Include "Hangup" button
 *			    'Join'   - Include "Join" button
 *                          'Monitor'- Include "Monitor" button
 *			    'None'   - Do not include action button
 *	.action_data	Data used by action:
 *			    (e.g. "*#105" for action='Join')
 *			    (e.g. "0000091STOP" for action='Stop')
 *	.popup_title	Web-UI will use popup_title as the title for popups
 *	.scope		Recepient Scope for Message defined in .type
 *			    'All'   - ALL Web UI Users
 *			    'Admin' - Only Admin type Web UI Users
 *			    'Extension' - Only Web UI User define by .extension
 *	.extension	Extension related to message/popup (optional), or
 *			if scope='Extension', then dashboard_msg.extension
 *			defines the single Web UI recepient (see .scope).
 *	.play_audio_file If not blank, is the filename of audio file to play on Web UI.
 *	.identifier	Used in queries to find msgs to be deleted.
 *
 * NOTE: Using enum fields because this table is transient, it does not
 *       store real data.
 */
DROP TABLE IF EXISTS dashboard_msg;
CREATE TABLE dashboard_msg (
	id		int unsigned NOT NULL AUTO_INCREMENT,
	facility	int(5) NOT NULL DEFAULT '1',
	type		enum('911-popup','motd','popup','text') DEFAULT 'text',
	text		varchar(255),
	action		enum('Activate', 'Call','Delete','Hangup','Join','Monitor', 'None','Stop') DEFAULT 'None',
	action_data	varchar(128) DEFAULT '',
	popup_title	varchar(50) DEFAULT 'Alarm',
	scope		enum('All','Admin','Extension') DEFAULT 'Admin',
	extension	varchar(40) DEFAULT '',
	zones		varchar(512) NOT NULL DEFAULT '0',
	play_audio_file	varchar(128) DEFAULT '',
	repeat_period	decimal(2,1) unsigned NOT NULL DEFAULT '1.0',
	times_to_play	int(2) NOT NULL DEFAULT '0',
	time		timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
	message_style   enum('basic','success','info','warning','danger') DEFAULT 'basic',
	identifier	varchar(255) DEFAULT '',
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
