USE asterisk;
/*
 *
 * Device Monitor configuration
 * To prevent device monitoring, set enable to FALSE
 *
 * startup_sleep - How long to wait for devices to register on startup
 *
 * no_devices_sleep - If no devices to monitor, how long to wait before
 *                    checking for new devices.
 *
 * tftp_config_check_interval - How often (in seconds) to check for added
 *                              or deleted device configuration files.
 *
 * send_email_to - Comma separated list of email recepients for alerts,
 *                 or smtp.account to use.
 *                 If left blank, email alerts will not be sent.
 *
 * use_smtp_table - TRUE:  use SMTP configuration values from smtp table
 *                  FALSE: use STMP configuration from /etc/msmtprc
 *
 * valid_monitor_types: comma separated list of valid station types that user
 *                      can select from (used to define menu of types
 *			displayed via monitor_types field)
 *
 * monitor_types: comma separated list of station types to monitor
 *
 * skip_stations: comma separated list of stations to skip monitoring
 *
 */
DROP TABLE IF EXISTS device_monitor;
CREATE TABLE device_monitor (
	id			int unsigned NOT NULL AUTO_INCREMENT,
	enable			boolean NOT NULL DEFAULT '1',
	startup_sleep		int(5) NOT NULL DEFAULT '120',
	no_devices_sleep	int(5) NOT NULL DEFAULT '60',
	tftp_config_check_interval	int(5) NOT NULL DEFAULT '30',
	rsyslog_enable		boolean NOT NULL DEFAULT '0',
	rsyslog_config		boolean NOT NULL DEFAULT '1',
	rsyslog_facility	enum('local0','local1','local2','local3','local4','local5','local6','local7','user') NOT NULL DEFAULT 'local7',
	send_email_to		varchar(2048) DEFAULT '',
	use_smtp_table		boolean NOT NULL DEFAULT '1',
	smtp_account		varchar(80) DEFAULT '',
	email_subject		varchar(128) DEFAULT 'Nyquist Alert',
	valid_monitor_types	varchar(255) DEFAULT '1,4,5,7,10,11,21,22,23,24,27,28',
	monitor_types		varchar(255) DEFAULT '1,4,5,7,10,11,21,22,23,24,27,28',
	skip_stations		varchar(4096) DEFAULT '',
PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
