/*
 * This table contains display settings for GA10PV devices.
 *
 * extension	- The extension the display is linked to.
 * type		- The display type.
 * date_format	- The format of the day, month, year on the display.
 * show_date	- Hide/show the date text.
 * show_event	- Hide/show the event text.
 * background_color	- The color of the display background.
 * text_color	- The date and event text color.
 * text_font	- The date and event text font.
 * text_size	- The date and event text size.
 * time_format  - The digital clock 12/24 hour format.
 * time_color	- The digital clock time text color.
 * time_font	- The digital clock time text font.
 * time_size	- The digital clock time text size.
 * checkin_*	- These variables are used when the GA10PV participates in the Check-in process.
 */
DROP TABLE IF EXISTS display;
CREATE TABLE display (
	id		int unsigned NOT NULL AUTO_INCREMENT,
	extension	varchar(40),
	type		enum ('analog_clock','digital_clock','messages_1_column','messages_2_columns','messages_3_columns') DEFAULT 'analog_clock',	
	date_format	enum ('DDD, MMM DD','MMM DD, YYYY','DD MMM YY','DD MMM YYYY','DD/MM/YY','DD/MM/YYYY','MM/DD/YY','MM/DD/YYYY') DEFAULT 'DDD, MMM DD',
	show_date	boolean NOT NULL DEFAULT 1,
	show_event	boolean NOT NULL DEFAULT 1,
	show_seconds    boolean NOT NULL DEFAULT 1,
	background_color        varchar(20) DEFAULT 'rgb(255,255,255)',
	text_color	varchar(20) DEFAULT 'rgb(0,0,0)',
	text_font	enum ('Comic-Relief','Courier-Prime','Gelasio','Liberation-Sans','Linux-Libertine') DEFAULT 'Liberation-Sans',
	text_size 	int DEFAULT '70',
	time_format	enum ('12','24') DEFAULT '12',
	time_color	varchar(20) DEFAULT 'rgb(0,0,0)', 
	time_font	enum ('Comic-Relief','Courier-Prime','Gelasio','Liberation-Sans','Linux-Libertine') DEFAULT 'Liberation-Sans',
	time_size	int DEFAULT '400',
	checkin_enabled	boolean NOT NULL DEFAULT 0,
	checkin_font_size_min	int DEFAULT '50',
	checkin_show_name	boolean NOT NULL DEFAULT 1,
	checkin_show_not_checked_in_only	boolean NOT NULL DEFAULT 0,
	checkin_show_vacant	boolean NOT NULL DEFAULT 1,
	checkin_show_excluded	boolean NOT NULL DEFAULT 0,
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
