/*
 * Gateways
 *
 * This table defines available gateway devices,
 * also known as Analog-Station-Bridge devices.
 *
 * .master_volume - should be copied to all associated stations, but should
 *                  be read-only on the station view.
 *
 * The following fields should be copied to associated stations and be editable
 * via station edit: day_cos, night_cos, day_admin, night_admin, 911_route
 *
 * The following fields should be copied to associated stations but not be
 * editable via station edit: vlan_config, vlan_id, priority_802_1p
 *
 */
DROP TABLE IF EXISTS gateway;
CREATE TABLE gateway (
        id                      int unsigned NOT NULL AUTO_INCREMENT,
	name			varchar(16),
        mac_address             varchar(12) DEFAULT '',
	ip_address		int unsigned NULL DEFAULT 0,  
	status			varchar(20) DEFAULT 'Unknown',
	enabled			boolean NOT NULL DEFAULT '1',
	description		varchar(128) DEFAULT 'Analog Station Bridge',
	master_volume		int(3) NOT NULL DEFAULT '0',
	intercom_volume		int(3) NOT NULL DEFAULT '-6',
	day_cos			int NOT NULL,
	night_cos		int NOT NULL,
	day_admin		varchar(16) DEFAULT '',
	night_admin		varchar(16) DEFAULT '',
	911_route		varchar(40) DEFAULT 'No Access',
        vlan_config             enum ('server','network','disabled'),
        vlan_id                 int(4) DEFAULT '2',
        priority_802_1p         int(1) DEFAULT '0',
	web_username            varchar(40) DEFAULT 'admin',
        web_password            varchar(40) DEFAULT 'bogen',
	serial_number		varchar(32) DEFAULT 'Unknown',
	fw_filename		varchar(128) DEFAULT '',
	output_power		varchar(16) NOT NULL DEFAULT '0',
PRIMARY KEY (id),
UNIQUE KEY `mac_addr` (`mac_address`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS gateway_help;
CREATE TABLE gateway_help (
	id			int unsigned NOT NULL AUTO_INCREMENT,
	name			varchar(32),
	mac_address		varchar(32),
	ip_address		varchar(128),
	status			varchar(256),
	enabled			varchar(128),
	description		varchar(32),
	master_volume		varchar(128),
	intercom_volume		varchar(128),
	day_cos			varchar(128),
	night_cos		varchar(128),
	day_admin		varchar(128),
	night_admin		varchar(128),
	911_route		varchar(128),
	vlan_config		varchar(128),
	vlan_id			varchar(64),
	priority_802_1p		varchar(64),
	web_username		varchar(128),
	web_password		varchar(128),
	serial_number		varchar(128),
	fw_filename		varchar(128),
	output_power		varchar(64),
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
