/*
 * This table contains messages to be displayed on GA10PV devices.
 * The messages will also be displayed on the dashboard (TBD).
 *
 * creator        - Station extension of message creator.
 * priority       - is used by queries to display messages in order of priority.
 *                  We can use integer values (low to high).
 * created        - date/time message was created.
 * expires        - date/time that message shall no longer be displayed.
 *                  A value of "0000-00-00 00:00:00" means always display until
 *                  message is deleted. If expires is not provided but a duration
 *                  is provided, the server will automatically set expires to
 *                  current time plus number of seconds specified in duration.
 *                  If users specify a specific date/time (or time), the web
 *                  interface shall set expires to match the desired expiration
 *                  provided by the user.
 * duration       - Number of seconds to display the message, expires after duration.
 *                  If duration is 0, and expires is not set, message shall be
 *                  displayed until deleted. If duration is 0 but expires has been
 *                  set, then the message shall be displayed until expires date/time.
 *                  Duration is available to be used by other input methods that
 *                  currently use duration (e.g. I/O controller rules)
 * zones          - Comma separated list of zones that shall receive the message.
 *                  Zone "0" is used to send to all displays.
 * stations       - Comma separated list of stations that shall receive the message.
 *                  When combined with zones, specifies additional stations to
 *                  include.
 * text           - The message ext to display.
 * background_color  - The message rounded rectangle color.
 * font           - The message text font.
 * font_style     - The message text font styles comma seperated.
 * font_size      - The message text font point size.
 * font_color     - The message text color.
 *
 */
DROP TABLE IF EXISTS message;
CREATE TABLE message (
	id			int unsigned NOT NULL AUTO_INCREMENT,
	creator			varchar(40),
	priority		int DEFAULT 0,
	created			timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
	expires			timestamp,
	duration		int DEFAULT 0,
	identifier		varchar(255) DEFAULT '',
	zones			varchar(4096),
	stations		varchar(4096),
	text			varchar(4096) DEFAULT '',
	background_color	varchar(20) DEFAULT 'rgb(0,255,0)',
	font			enum ('Comic-Relief','Courier-Prime','Gelasio','Liberation-Sans','Linux-Libertine') DEFAULT 'Liberation-Sans',
	font_style		varchar(200) DEFAULT '',
	font_size		int DEFAULT '70',
	font_color		varchar(20) DEFAULT 'rgb(0,0,0)',
	type            	enum ('text','image') DEFAULT 'text',
	image_type      	enum ('full','left','right') DEFAULT 'full',
	message_image_id	int DEFAULT 0,
	image_priority  	enum ('text','image') DEFAULT 'text',
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

/*
 * Setup event to automatically delete expired messages from message table.
 */
DROP EVENT IF EXISTS AutoDeleteOldMessages;

CREATE EVENT AutoDeleteOldMessages
ON SCHEDULE EVERY 1 HOUR
DO
DELETE FROM message WHERE ((expires < NOW()) AND (year(expires) != 0));
