/*
 * NQ-P0100 Matrix Mixer Pre-Amp Station Configuration
 *
 * mixer_config
 *	.extension	Station Extension of NQ-P0100 Matrix Mixer Pre-Amp
 *	.ptt_channel	Push-To-Talk Channel Number, 0 means PTT not configured
 *	.ptt_type	Push-To-Talk Activity Type
 *	.ptt_zones	Zone associated with PPT type = 'Zone Page'
 *	.ptt_src_to_out	Selects the input source to direct to output when PPT is pressed.
 *	.ptt_output	Selects the output device to use when PPT is activated.
 *
 * NOTE: ptt_type = 'Line-Output' is actually turned into "DSP-Controlled".
 *
 */
DROP TABLE IF EXISTS mixer_config;
CREATE TABLE mixer_config (
	id		int unsigned NOT NULL AUTO_INCREMENT,
	extension	varchar(40) NOT NULL,
	ptt_channel	int(3) NOT NULL DEFAULT '0',
	ptt_type	enum('All-Call-Page', 'Emergency-All-Call-Page', 'Line-Output', 'Multi-Site-All-Call-Page', 'Multi-Site-Emergency-All-Call-Page', 'Record-Zone-Page', 'Zone-Page','Disabled','Analog-Output') DEFAULT 'All-Call-Page',
	ptt_zones	varchar(255) DEFAULT '',
	ptt_src_to_out	enum('Analog','Network') DEFAULT 'Analog',
	ptt_output	enum('Both','Line-Out','None','Speaker-Out','Disabled') DEFAULT 'None',
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS mixer_config_help;
CREATE TABLE mixer_config_help (
	id		int unsigned NOT NULL AUTO_INCREMENT,
	extension	varchar(128),
	ptt_channel	varchar(128),
	ptt_type	varchar(128),
	ptt_zones	varchar(128),
	ptt_src_to_out	varchar(256),
	ptt_output	varchar(255),
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
