USE asterisk;
/*
 * Multicast RTP IP Address configuration
 *
 * This table is used to configure IP addresses for Multicast RTP streams.
 * We assume that 10 multicast streams are available (Snom phone provides 10).
 * We reserve one for All-Call/Emergency-All-Call paging, and reserve another
 * for Audio Distribution.
 *
 * multicast_rtp.id - This index represents the slot number to use for the
 *                    specified IP address.
 *
 * .zone_id - Id of the Zone (pagingzones.id) that uses the defined
 *            Multicast IP Address
 *
 * .multicast_ip_address - The IP Address to use for the RTP multicast stream
 *
 * .multicast_ip_port - The Port number to use for associated IP address
 *
 * NOTE: multicast_rtp.id = 1 is reserved for Audio Distribution.
 *       multicast_rtp.id = 10 is reserved for All-Call Page and
 *                          Emergency All-Call Page.
 *       multicast_rtp.id = (2..9) can be assigned to paging zones.
 *
 */
DROP TABLE IF EXISTS multicast_rtp;
SELECT 'Creating multicast_rtp table' AS ' ';
CREATE TABLE multicast_rtp (
	id			int unsigned NOT NULL AUTO_INCREMENT,
	zone_id			int(10) NOT NULL DEFAULT 0,
        multicast_ip_address	int unsigned NULL DEFAULT 0,
	multicast_ip_port	int unsigned NOT NULL DEFAULT 0,
PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS multicast_rtp_help;
SELECT 'Creating multicast_rtp_help table' AS ' ';
CREATE TABLE multicast_rtp_help (
	id			int(5) DEFAULT '1',
	multicast_ip_address	varchar(40),
	multicast_ip_port	varchar(40),
PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
