/*
 * This table contains defined actions for the associated routine.
 *
 * .routine_id - The associated routine that executes the action.
 *
 * .execute_order - Defines the order in which the actions shall be executed.
 *
 * .finish_delay - 'no-delay' indicates that the next action can be executed
 *                 before the current action has finished, possibly in parallel.
 *                 'wait-until-done' indicates that the next action should
 *                 not be started until the current action has finished
 *                 executing. Note: finished executing may simply mean that
 *                 a system executed script has returned from execution (even
 *                 though some action started by the script may still be
 *                 running.
 */
DROP TABLE IF EXISTS routine_action;
CREATE TABLE routine_action (
	id		int unsigned NOT NULL AUTO_INCREMENT,
	enabled		boolean NOT NULL DEFAULT 1,
	name		varchar(64) NOT NULL DEFAULT 'New Action',
	routine_id	int unsigned NOT NULL,
	execute_order	int NOT NULL,
	finish_delay	enum ('no-delay','wait-until-done') NOT NULL DEFAULT 'no-delay',
	type		enum (	'911',
				'alarm',
				'all-call',
				'announcement',
				'audio-dist-start',
				'audio-dist-stop',
				'check-in',
				'check-intercom',
				'dash-delete',
				'dash-text',
				'disable-audio',
				'display-msg',
				'display-msg-delete',
				'enable-audio',
				'email',
				'emergency-call',
				'emerg-all-call',
				'facility-page',
				'feature-wait',
				'intercom-call',
				'intercom-wait',
				'multi-site-all-call',
				'multi-site-e-all-call',
				'no-action',
				'output-contact-close',
				'output-contact-open',
				'page-exclusion',
				'pause',
				'ring-wait',
				'routine',
				'tone',
				'urgent-call',
				'zone-page',
				'play-ringtone',
				'call-and-announce',
				'routine-disable',
				'routine-enable',
				'new-announcement',
				'add-announcement-audio',
				'play-announcement',
				'change-volume',
				'goto',
				'change-setting'
			) NOT NULL DEFAULT 'no-action',
	action_condition varchar(4095) DEFAULT '',
	param1		varchar(4095) DEFAULT '',
	param2		varchar(4095) DEFAULT '',
	param3		varchar(4095) DEFAULT '',
	param4		varchar(4095) DEFAULT '',
	description	varchar(255) DEFAULT '',
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
