/*
 *
 * SIP Trunks
 *
 * sip_trunk
 *	.type	= telephony_port_types.id
 *	.access	= outside_line_access_types.id
 *	.allow	= Values from system.default_codecs_allowed
 *	.status = Text string set by update-siptrunks-status script.
 *
 */
DROP TABLE IF EXISTS sip_trunk;
CREATE TABLE sip_trunk (
	id			int unsigned NOT NULL AUTO_INCREMENT,
	facility		int(5) NOT NULL,
	name			varchar(40) NOT NULL,
	description		varchar(128),
	enabled			boolean NOT NULL DEFAULT TRUE,
	status			varchar(80),
	`access`		int DEFAULT '2',
	extension		varchar(40),
	did			varchar(16),
	username		varchar(40) NOT NULL,
	password		varchar(80) NOT NULL,
	host			varchar(80) NOT NULL,
	dial_prefix		varchar(40) DEFAULT '',
	local_areacode		varchar(3) DEFAULT '',
	`type`			int(2) NOT NULL DEFAULT '3',
	day_admin		varchar(16) NOT NULL,
	night_admin		varchar(16) NOT NULL,
	admin_group		int NOT NULL,
	allow			varchar(200) DEFAULT 'g722;ulaw;speex',
	disallow		varchar(200) DEFAULT 'all',
	has_call_recording	boolean NOT NULL DEFAULT FALSE,
	custom_settings		varchar(1024) DEFAULT '',
	context			varchar(40) NOT NULL DEFAULT 'incoming',
	dtmf_mode		varchar(40) NOT NULL DEFAULT 'rfc4733',
	911_digits		varchar(15) NOT NULL DEFAULT '911',
	allow_outbound_intercom_calls	boolean NOT NULL DEFAULT FALSE,
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS sip_trunk_help;
CREATE TABLE sip_trunk_help (
	id			varchar(8) DEFAULT '',
	facility		varchar(128),
	enabled			varchar(128),
	name			varchar(128),
	description		varchar(128),
	status			varchar(128),
	extension		varchar(128),
	username		varchar(128),
	password		varchar(128),
	host			varchar(128),
	dial_prefix		varchar(128),
	local_areacode		varchar(128),
	`type`			varchar(128),
	`access`		varchar(128),
	did			varchar(128),
	day_admin		varchar(128),
	night_admin		varchar(128),
	admin_group		varchar(128),
	disallow		varchar(128),
	allow			varchar(128),
	context			varchar(128),
	dtmf_mode		varchar(128),
	has_call_recording	varchar(128),
	custom_settings		varchar(128),
	allow_outbound_intercom_calls	varchar(128),
PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
INSERT INTO sip_trunk_help (facility, enabled, name, description, status, extension, username, password, host, dial_prefix, local_areacode, type, access, did, day_admin, night_admin, admin_group, disallow, allow, context, dtmf_mode, has_call_recording, custom_settings, allow_outbound_intercom_calls)
VALUES	('Facility ID.',
	 'Enable/disable SIP Trunk.',
	 'Local name for this SIP Trunk (no spaces or / character).',
	 'Local description for SIP Trunk.',
	 'Current status of SIP Trunk.',
	 'Station extension associated with the SIP Trunk (DISA station mapping and CallerID for incoming DISA).',
	 'Username for accessing the SIP Trunk.',
	 'Password for accessing the SIP Trunk.',
	 'Internet Telephony Service Provider Hostname or IP Address.',
	 'Dial prefix required by ITSP (e.g. +1).',
	 'Local Area Code - Set this value ONLY if the trunk provider requires local 7-digit calls to be prefixed with area code.',
	 'SIP Trunk Type.',
	 'Outside Access permissions for the SIP Trunk.',
	 'DID attached to the SIP Trunk.',
	 'Day Admin to ring for incoming calls during day time.',
	 'Night Admin to ring for incoming calls during night time.',
	 'Admin Group to forward incoming call to if day/night admin do not answer.',
	 'List of media codecs to disallow, seperated by semicolon.',
	 'List of media codecs to allow, seperated by semicolon.',
	 'Dialplan context to use for incoming calls from this SIP Trunk.',
	 'DTMF Mode: rfc4733, inband, info, auto.',
	 'When enabled, incoming/outgoing calls will be recorded.',
	 'Custom configuration settings supplied by Technical Support.',
	 'When enabled, the SIP Trunk can be used by Stations to place intercom calls to PBX-based Admin extensions.');
SELECT * FROM sip_trunk_help;
