/*
 *
 * Yealink Line-Key Mappings Menu Selections
 *
 * yealink_linekey_menu.
 *	default_key_pos	The linekey number that contains this feature by default.
 *	menu_label	Label to display in drop-down selection menu.
 *	key_*		The values to store in the yealink_linekey table for selected linekey of extension being edited.
 *	check_cos	CoS permission that must be enabled for extension before menu selection is displayed;
 *			one exception, schools_sites is from station.schools.sites.
 *			The yealink_linekey_menu.check_cos value should be copied to yealink_linekey.x_cos (where x is linekey number).
 *
 * key_type options:
 *
 * Empty	Leave linekey blank, no feature defined.
 * 13		Speed Dial (use by Nyquist defined speed dial keys and Custom Speed Dial keys)
 * 27		XML URL (for touch menus created by Nyquist)
 * Reserved	Linekey is reserved for customer use. Nyquist will not touch it.
 * Zone		Linekey is for Paging Zone, zones sorted by number, first come, first serve.
 *		When key_type is 'Zone', the key_label can contain formatting commands:
 *			$name for paging zone name
 *			$number for paging zone number.
 *		Example: key_label = "Zone$number: $name"
 *			For zone 1 with name "Outdoor" label would be "Zone1: Outdoor"
 *		If key_label is '', the default format is: "Z$number: $name".
 *
 */
DROP TABLE IF EXISTS yealink_linekey_menu;
CREATE TABLE yealink_linekey_menu (
	id		int unsigned NOT NULL AUTO_INCREMENT,
	default_key_pos	tinyint(2) NOT NULL,
	menu_label	varchar(30),
	key_type	enum ('Empty','13','27','Reserved','Zone') NOT NULL,
	key_line	tinyint(2) NOT NULL DEFAULT '1',
	key_value	varchar(99) NOT NULL DEFAULT '',
	key_label	varchar(30) NOT NULL DEFAULT '',
	check_cos	varchar(40) NOT NULL DEFAULT '',
PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

INSERT INTO yealink_linekey_menu (default_key_pos, menu_label, key_type, key_line, key_value, key_label, check_cos)
VALUES	( '7','All-Call','13','1','#0','All-Call','has_all_call_page'),
	( '9','Announcements','27','1','tftp://$server_ipaddr/Announcements.xml','Announce','has_all_call_page|has_zone_paging'),
	('10','Audio Distribution','27','1','tftp://$server_ipaddr/progDistList.xml','Audio          Distribution','has_program_distribution'),
	( '0','Custom Speed Dial','13','1','','',''),
	( '0','Empty','Empty','1','','',''),
	( '8','Emergency All-Call','13','1','#0911','Emergency   All-Call','has_emergency_all_call'),
	( '5','Multi-Site All-Call','13','1','##0','Multi-Site      All-Call','has_multiserver_paging'),
	( '6','Multi-Site Emergency-All-Call','13','1','##0911','Multi-Site      Emerg-All-Call','has_multiserver_paging'),
	( '3','Record Page','13','1','*991','Record        Page','has_zone_paging'),
	( '2','Reserved','Reserved','1','','',''),
	( '4','Routines','27','1','tftp://$server_ipaddr/Routines.xml','Routines','has_execute_routines'),
	('11','Schedules','27','1','tftp://$server_ipaddr/schedList-$deviceMac.xml','Schedules','schools_sites'),
	('12','Zone','Zone','1','','','has_zone_paging');
	/* Line Keys 12 - 29 are displayed when the "+ More" button is pressed */
