/*
 * cos_defs can be used by the Web UI for assistance to know
 *  which CoS attributes to display on the CoS Template configuration
 *  screen.
 *
 *  If cos_defs.supported is TRUE, the row should be included in
 *  drop-down selection list presented to the user; otherwise it
 *  should not be included. For CoS attributes that are not
 *  collected by the user because .supported is FALSE, the DEFAULT
 *  value for the associated attribute will be FALSE, and the
 *  system will not use it.
 *
 *  .type provides a hint at the type of data to collect. If type is an
 *   enum, the value will contain the enum's table name (e.g. callin_level_enum)
 *   Some valid bool_* values are bool_checkbox, bool_yesno, bool_truefalse
 *
 *  .display_name provides text to display in the drop-down selection list.
 *
 *  .db_field provides the column name to use in the cos table for UPDATE.
 *
 *  .help can be used to display help for flyover or other help initiation.
 *
 *  .id will always remain the same per row, new columns will be appended.
 *
 */
TRUNCATE TABLE cos_defs;
INSERT INTO cos_defs (id, type, supported, display_name, db_field, help)
VALUES	(1, "callin_level_enum", TRUE, "Call in Level", "callin_level", "For call switch and handset station types, identifies the call as Normal+Emergency, Urgent+Emergency or Emergency Only."),
	(2, "bool_checkbox", TRUE, "Zone Paging", "has_zone_paging", "Enables the station to perform zone paging."),
	(3, "bool_checkbox", TRUE, "All-Call Paging", "has_all_call_page", "Enables the station to simultaneously page all speakers within the facility."),
	(4, "bool_checkbox", TRUE, "Emergency All-Call", "has_emergency_all_call", "Enables the station to place a top priority all-call page."),
	(5, "bool_checkbox", TRUE, "Inter-Facility Call/Page", "has_interfacility_callpage", "Provides the ability to call another facility via the facilities list."),
	(6, "bool_checkbox", TRUE, "Audio Distribution", "has_progam_distribution", "Enables the distribution of audio program material to stations and zones."),
	(7, "bool_checkbox", TRUE, "Remote Pickup", "has_remote_pickup", "Remote answering of internal and incoming outside line calls."),
	(8, "bool_checkbox", TRUE, "Join Conversation", "has_bump_join", "Enables the caller to join an existing call."),
	(9, "bool_checkbox", TRUE, "Call Forwarding", "has_call_forwarding", "Permits a user to redirect or route incoming calls to another station."),
	(10, "bool_checkbox", TRUE, "Walking Class of Service", "has_walking_cos", "Enables manual override of telephone restrictions."),
	(11, "bool_checkbox", TRUE, "External Call Routing", "has_external_call_routing", "Enables the station to transfer a call to an outside line."),
	(12, "bool_checkbox", TRUE, "Call Transfer/3-way Calling", "has_call_transfer", "Allows the station user to contact a third-party while on a call, establish a three-way conversation and then drop off allowing the two other parties to remain connected."),
	(13, "bool_checkbox", TRUE, "Manually Activate Tone Signals", "has_manual_activate_tone", "Allows the station user to initiate tones outside of the schedule."),
	(14, "bool_checkbox", TRUE, "Call Any Station", "has_call_anystation", "Allows the station user to initiate calls to any station. When not enabled, the station user can only call Admin stations."),
	(15, "bool_checkbox", TRUE, "Manage Recordings", "has_manage_recordings", "Allows the station user to manage recordings (e.g. Emergency call recordings)."),
	(16, "bool_checkbox", TRUE, "Monitor Calls", "has_call_monitoring", "Allows the station user to monitor active calls."),
	(17, "bool_checkbox", TRUE, "Monitor Locations", "has_loc_monitoring", "Allows the station user to monitor station locations (not active calls)."),
	(18, "bool_checkbox", TRUE, "Conference Admin", "has_conf_admin", "Allows the station user to create or join a conference as an administrator."),
	(19, "bool_checkbox", TRUE, "Conference User", "has_conf_user", "Allows the station user to join a conference as a user."),
	(20, "bool_checkbox", TRUE, "Voicemail", "has_voicemail", "Allows the station user to receive voicemail."),
	(21, "bool_checkbox", TRUE, "Record Calls", "has_call_recording", "Allows the station user to start recording of their active call by pressing *3 anytime during the call."),
	(22, "bool_checkbox", TRUE, "Activate Alarm Signals", "has_activate_alarms", "Allows the station user to activate alarms."),
	(23, "bool_checkbox", TRUE, "Disable Audio", "has_disable_audio", "Allows a station with contact closure to disable audio during Fire Alarm or other emergency events."),
	(24, "bool_checkbox", TRUE, "Enable Audio", "has_enable_audio", "Allows a station user to enable audio previously disabled during an emergency event (e.g. Fire Alarm)."),
	(25, "bool_checkbox", TRUE, "Allow Callee Auto-answer", "has_callee_autoanswer", "When enabled, allows call auto-answer by the callee, for calls placed by this station user."),
	(26, "bool_checkbox", TRUE, "Multi-Site Paging", "has_multiserver_paging", "When enabled, allows station to perform multi-site paging to all sites."),
	(27, "bool_checkbox", TRUE, "Inter-Facility Features", "has_interfacility_features", "When enabled, allows station to call feature extensions on remote facilities."),
	(28,"bool_checkbox", TRUE, "Manage Output Contacts", "has_manage_output_contacts", "When enabled, allows station to activate / reset output contacts on I/O Controllers."),
	(29,"bool_checkbox", TRUE, "Execute Routines", "has_execute_routines", "When enabled, allows station to execute routines via DTMF.");
SELECT * FROM cos_defs;
