/*
 * The product_feature table contains configuration information for all features
 * (e.g. Zones, Stations, Admin Group, CoS)
 *
 * .is_enabled - indicates that the feature is enabled.
 *
 * .has_navgroup - indicates that the feature is enabled and should be displayed
 *  to the user via the navigation pane.
 *
 *  If .has_navgroup is TRUE, then .parent may indicate a tree relationship
 *  between other features.
 *  The value 'root' is special, it means the navgroup is the root of the tree.
 *  If .has_navgroup is FALSE, the value 'feature' is used for .parent.
 *
 * .name is for doing row SELECT
 *	Example, to see if Audio Distribution is enabled:
 * 	SELECT is_enabled FROM product_feature WHERE name='audiodist';
 *
 */
TRUNCATE TABLE product_feature;
INSERT INTO product_feature (id, is_enabled, has_navgroup, has_link, sort_order, name, parent, label, label_plural, class_name, glyph_name, icon_filename, permission)
VALUES
	(1,1,0,0,0,'product','feature','Nyquist C4000','Nyquist C4000','','rocket','nyquist.jpg',''),
	(2,0,0,0,0,'facility','root','Facility','Facility','','cube','facility.jpg','view_facilities'),
	(3,1,1,1,2,'system','facility','System Parameter','System Parameters','system','list-ol','system.jpg','view_systems'),
	(4,1,1,1,4,'zone','zones_and_queues','Zone','Zones','paging-zones','bullhorn','zone.jpg','view_zones'),
	(5,0,0,0,0,'bell_schedule','schedules_menu','Schedule','Schedules','bell-schedule','bell-o','schedule.jpg','view_schedules'),
	(6,1,1,1,7,'settings','schedules_menu','Site','Site','schedule-settings','building-o','calendar.jpg','view_schedule_settings'),
	(7,1,1,1,8,'calendar','schedules_menu','Calendar','Calendars','schedule','calendar','calendar.jpg','view_calendars'),
	(8,1,1,1,9,'holiday','schedules_menu','Holiday','Holidays','holidays','calendar-check-o','holiday.jpg','view_holidays'),
	(9,1,1,1,10,'schedule_announcements','schedules_menu','Schedule Announcement','Schedule Announcements','schedule_announcements','volume-up','schedule_announcements.jpg','view_schedule_announcements'),
	(10,1,1,1,13,'admingroup','facility','Admin Group','Admin Groups','admin_group','users','admingroup.jpg','view_admin_groups'),
	(11,1,1,1,12,'cos','facility','CoS Configuration','CoS Configuration','cos','cogs','cos.jpg','view_cos'),
	(12,0,1,0,0,'neighbor','facility','Neighbor','Neighbors','','home','neighbor.jpg',''),
	(13,0,1,0,0,'node','facility','Node','Nodes','','code-fork','node.jpg',''),
	(14,1,1,1,15,'station','facility','Station','Stations','station','phone','station.jpg','view_stations'),
	(15,0,0,0,0,'station_num','feature','Arch #','Arch #','','cube','station.jpg',''),
	(16,0,0,0,0,'intercom','feature','Intercom','Intercom','','microphone','intercom.jpg',''),
	(17,0,0,0,0,'audiodist','feature','Audio Distribution','Audio Distribution','','volume-down','audiodist.jpg',''),
	(18,0,0,0,0,'nr_admin','none','Night Ring Admin','','','','',''),
	(19,0,0,0,0,'nr_admin_group','none','Night Ring Admin Group','','','','',''),
	(20,0,0,0,0,'nr_zones','none','Night Ring Zones','','','','',''),
	(21,0,0,0,0,'nr_all_stations','none','Night Ring All Stations','','','','',''),
	(22,0,0,0,0,'admin','none','Admin','','','','',''),
	(23,1,1,0,17,'audio','facility','Audio','Audio','audio','volume-off','audio.jpg','view_audio'),
	(24,1,1,1,18,'announcement','audio','Announcement','Announcements','announcement','volume-up','announcement.jpg','view_announcements'),
	(25,1,1,1,20,'recording','audio','Recording','Recordings','recording','microphone','recording.jpg','view_recordings'),
	(26,1,1,1,22,'tone','audio','Tone','Tones','tone','music','tone.jpg','view_tones'),
	(27,1,1,1,24,'user','facility','User','Users','user','user','user.jpg','view_users'),
	(28,1,1,1,25,'role','facility','Role','Roles','role','key','role.jpg','view_roles'),
	(29,0,0,0,0,'permission','facility','Permission','Permissions','permission','lock','permission.jpg',''),
	(30,0,0,0,0,'default-schedule','facility','Schedule','Schedules','default-schedules','calendar-o','default-schedule.jpg',''),
	(31,0,0,0,0,'event','facility','Event','Events','schedule-events','calendar-plus-o','schedule-event.jpg',''),
	(32,0,0,0,34,'help','facility','Help','Help','help','life-ring','help.jpg','view_help'),
	(33,0,0,0,36,'help_topics','help','Help Topic','Help Topics','help/topics','question-circle-o','help_topics.jpg','view_help'),
	(34,1,1,0,6,'schedules_menu','facility','Schedule','Schedules','','calendar-o','schedules_menu.jpg','view_schedules_menu'),
	(35,1,1,1,27,'outside_lines','facility','Outside Line','Outside Lines','outside_lines','code-fork','outside_line.jpg','view_outside_lines'),
	(36,1,1,1,28,'sip_trunks','facility','SIP Trunk','SIP Trunks','sip_trunks','exchange','sip_trunks.jpg','view_sip_trunks'),
	(37,1,1,1,29,'call_details','facility','Call Detail','Call Details','call_details','list','call_details.jpg','view_call_details'),
	(38,1,1,1,30,'system_backup','facility','System Backup/Restore','System Backup/Restore','system_backup','database','system_backup.jpg','view_system_backup'),
	(39,0,0,0,0,'backup_settings','none','Backup Settings','Backup Settings','backup_settings','list-ol','backup_settings.jpg',''),
	(40,1,1,1,21,'songs','audio','Song','Songs','songs','play-circle','songs.jpg','view_songs'),
	(41,1,1,1,19,'playlists','audio','Playlist','Playlists','playlists','list-alt','playlists.jpg','view_playlists'),
	(42,1,1,1,31,'system_log','facility','System Log','System Logs','system_log','file-text-o','system_log.jpg','view_system_log'),
	(43,1,1,1,32,'paging_exclusion','facility','Paging Exclusion','Paging Exclusions','paging_exclusion','ban','page_exclusion.jpg','view_paging_exclusions'),
	(44,1,1,1,26,'server','facility','Facility','Facilities','server','cubes','neighbor.jpg','view_neighbors'),
	(45,1,0,0,0,'new_station','none','New Station','New Stations','new_station','phone','new_station.jpg','view_stations'),
	(46,0,0,0,14,'gateway','facility','Bridge Device','Bridge Devices','gateway','arrows-alt','gateway.jpg','view_gateways'),
	(47,0,0,0,0,'ctrl_rule','none','Controller Rule','Controller Rules','ctrl_rule','file-text-o','ctrl_rule.jpg',''),
	(48,1,1,1,33,'firmware','facility','Firmware','Firmware','firmware','microchip','firmware.jpg','view_firmware'),
	(49,0,0,0,0,'mixer_config','none','Push To Talk Configuration','Push To Talk Configurations','mixer_config','file-text-o','mixer_config.jpg',''),
	(50,0,0,0,0,'mixer_channel','none','Mixer Channel','Mixer Channels','mixer_channel','sliders','mixer_channel.jpg',''),
	(51,0,0,0,0,'io_contact_sched','none','Output Contact Event','Output Contacts Daily Schedule','io_contact_sched','calendar','io_contact_sched.jpg',''),
	(52,0,0,0,35,'about','help','About','About','help/about','info-circle','about.jpg','view_help'),
	(53,0,0,0,37,'admin_manual','help','Admin Manual','Admin Manual','help/NyquistSystemAdministratorManual','file-pdf-o','admin_manual.jpg','view_help'),
	(54,1,1,1,23,'internet_sources','audio','Internet Radio Services','Internet Radio Services','internet_sources','rss','internet_sources.jpg','view_internet_sources'),
	(55,0,0,0,0,'service','audio','Credential','Credentials','service','address-card-o','service.jpg','view_services'),
	(56,0,0,0,0,'device_monitor','facility','Station Supervision','Station Supervision','device_monitor','sitemap','device_monitor.jpg','view_systems'),
	(57,0,0,0,0,'smtp','facility','Email Configuration','Email Configuration','smtp','envelope-o','smtp.jpg','view_systems'),
	(58,1,1,0,3,'zones_and_queues','facility','Zones and Queues','Zones and Queues','zones_and_queues','bullhorn','zones_and_queues.jpg','view_zones_and_queues'),
	(59,1,1,1,5,'zones_queue','zones_and_queues','Queue','Queues','zones_queue','bars','zones_queue.jpg','view_queues'),
	(60,1,1,1,16,'amplifier','facility','Amplifier and Gateway Devices','Amplifier and Gateway Devices','amplifier','server','amplifier.jpg','view_amplifiers'),
	(61,0,0,0,0,'intercom_config','none','Intercom Module Configuration','Intercom Module Configurations','intercom_config','file-text-o','intercom_config.jpg',''),
	(62,1,1,1,38,'routine','facility','Routine','Routines','routine','random','routine.jpg','view_routines'),
	(63,0,0,0,0,'action','none','Action','Actions','action','bolt','action.jpg','view_actions'),
	(64,0,0,0,0,'trigger','none','Trigger','Triggers','trigger','arrow-circle-o-right','trigger.jpg','view_triggers'),
	(65,0,0,0,0,'checkin','none','Manage Check-in','Manage Check-ins','checkin','check-square-o','checkin.jpg','view_checkins'),
	(66,0,0,0,0,'ssu','none','Configure Automatic Software Download','Configure Automatic Software Download','ssu','cog','ssu.jpg',''),
	(67,0,0,0,0,'system_update','none','System Update','System Update','system_update','download','system_update.jpg',''),
	(68,1,1,1,39,'weather_alert_filter','facility','Alert Filter','Alert Filters','weather_alert_filter','warning','weather_alert_filter.jpg','view_weather_alert_filters'),
	(69,1,1,1,41,'message_template','messages','Message Template','Message Templates','message_template','file-text-o','message_template.jpg','view_message_templates'),
	(70,1,1,1,42,'message_image','messages','Message Image','Message Images','message_image','picture-o','message_image.jpg','view_message_images'),
	(71,1,1,0,40,'messages','facility','Message','Messages','messages','comment','messages.jpg','view_messages'),
	(72,1,1,1,43,'automatic_failover','facility','Automatic Failover','Automatic Failover','automatic_failover/1/edit','shield','automatic_failover.jpg','view_automatic_failover'),
	(73,1,1,1,11,'scheduled_routines','schedules_menu','Schedule Routine','Schedule  Routines','scheduled_routines','random','scheduled_routines.jpg','view_scheduled_routines'),
	(74,0,0,0,0,'custom_config','none','Custom Configuration','Custom Configuration','custom_config','wrench','custom_config.jpg','');
SELECT * FROM product_feature;
