USE asterisk;
/*
 * System Definition
 *
 * This table represents a system, otherwise known as a facility
 * A row in the system table exists for each facility being managed.
 *
 * system.id          - is the facility number
 *  .name             - is the facility name (for display)
 *  .day_start        - HH:MM representing start of day
 *  .night_start      - HH:MM representing start of night 
 *  .ip_multicast_rtp - IP Adress for Multicast RTP
 *  .disable_preannounce_tone - TRUE will disable paging preannounce tone
 *  .default_system_password  - When a user adds a new station, this is the
 *                              default password for the password field.
 *  .dialing_length   - Specifies the number of digits required to dial
 *                      within the system.
 *  .emergency_tone   - Defines pre-announce tone played when an Emergency
 *                      All-Call is made.
 *  .default_codecs_allowed - Default value for ps_endpoints.allow
 *                            which is the list of Media Codecs allowed.
 *
 *  .valid_codec_list	- A semi-colon seperated list of codecs that are
 *			  selectable in the default_codecs_allowed drop down
 *
 *  .all_call_tone    - Defines the pre-announce tone played when an All-Call 
 *                      is made.
 *
 *  .privacy_beep	- TRUE will enable privacy beep
 *
 *  .admin_queue_timeout - Timeout for admin phone queues.
 *
 *  .nightring_zonelist - List of Zones to ring (2500 allows for 500 Zones).
 *
 *  .nightring_stationlist - List of stations from zones (12000 allows for 1000 stations).
 *  .trunk_priority - Trunk type to use first (trunk_priority_enum.id)
 *  .bump_on_emergency - If true, bump existing admin call in favor of incoming
 *                       emergency call to admin.
 *  .bump_on_911 - If true, bump existing trunk call in favor of outgoing
 *                 call to 911.
 *  .backup_dir - Directory used to store system backups.
 *
 */
TRUNCATE TABLE system;
INSERT INTO system (id, name, day_start, night_start, ip_multicast_rtp, disable_preannounce_tone, default_station_password, dialing_length, emergency_tone, default_codecs_allowed, valid_codec_list, all_call_tone, privacy_beep, intercom_tone, default_volume, ip_ntp_server, admin_queue_timeout, time_zone, dhcp_override, server_ipaddr, audiodist_multicast_ip, parking_lot, record_monitoring, emergency_link, max_restricted_digits, disa_password, security_disa_password, call_log_length, trunk_priority, bump_on_emergency, bump_on_911, auth_code, call_assurance_audio,ip_multicast_port, audiodist_multicast_port, neighbor_secret, remote_facility_cos, allcall_multicast_ip, allcall_multicast_port,vlan_enabled,vlan_id,priority_802_1p)
VALUES ('1', 'Main Facility', '08:00', '17:00', INET_ATON('239.1.1.1'), FALSE, 'bogen', 3, '/var/lib/asterisk/sounds/pre/beep_sine_500hz-1', 'g722;opus;speex;ulaw', 'all;adpcm;alaw;g719;g722;g723;g726;g726aal2;g729;gsm;opus;siren7;siren14;slin;speex;ulaw', '/var/lib/asterisk/sounds/pre/burst', FALSE, '/var/lib/asterisk/sounds/pre/burst', 20, 'pool.ntp.org', 30, 'America/New_York', 0, INET_ATON('192.168.60.231'), INET_ATON('239.1.1.3'), '20-29', FALSE, '999', '10', '6459', '6459', '30', '1', '1', '1', '0000', 'call-placed', '6000', '6008', 'BogenSrvNyq1', '1', INET_ATON('239.1.1.2'), '6004', '0', '0', '0');
SELECT * FROM system;
