/*
 *
 * Yealink Line-Key Mappings for C4000 Systems
 *
 * 29 Line keys exist on the T48
 *
 * yealink_linekey.
 *	extension	The Station Extension owning this row of linekey definitions.
 *	type_x		Linekey type (Enum: NULL = Erase, 0 = Available for Zone, 13 = Speed Dial, 27 = XML Browser)
 *	line_x		Line number to apply the key feature (Range: 1 - 16)
 *	value_x		Value for the line key feature (99 character max.)
 *	label_x		Label to display on the linekey (30 character max.), yealink supports 99, but only 30 are displayed.
 *	cos_x		CoS permission that must be enabled for extension before key feature is placed on Admin Phone's linekey.
 */
DROP TABLE IF EXISTS yealink_linekey;
CREATE TABLE yealink_linekey (
	id		int unsigned NOT NULL AUTO_INCREMENT,

	extension	varchar(40),

	type_1		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Reserved',
	line_1		tinyint(2) NOT NULL DEFAULT '1',
	value_1		varchar(99) NOT NULL DEFAULT '',
	label_1		varchar(30) NOT NULL DEFAULT '',
	cos_1		varchar(40) NOT NULL DEFAULT '',

	type_2		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Reserved',
	line_2		tinyint(2) NOT NULL DEFAULT '1',
	value_2		varchar(99) NOT NULL DEFAULT '',
	label_2		varchar(30) NOT NULL DEFAULT '',
	cos_2		varchar(40) NOT NULL DEFAULT '',

	type_3		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '13',
	line_3		tinyint(2) NOT NULL DEFAULT '1',
	value_3		varchar(99) NOT NULL DEFAULT '*991',
	label_3		varchar(30) NOT NULL DEFAULT 'Record        Page',
	cos_3		varchar(40) NOT NULL DEFAULT 'has_zone_paging',

	type_4		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '27',
	line_4		tinyint(2) NOT NULL DEFAULT '1',
	value_4		varchar(99) NOT NULL DEFAULT 'tftp://$server_ipaddr/Routines.xml',
	label_4		varchar(30) NOT NULL DEFAULT 'Routines',
	cos_4		varchar(40) NOT NULL DEFAULT 'has_execute_routines',

	type_5		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '13',
	line_5		tinyint(2) NOT NULL DEFAULT '1',
	value_5		varchar(99) NOT NULL DEFAULT '##0',
	label_5		varchar(30) NOT NULL DEFAULT 'Multi-Site      All-Call',
	cos_5		varchar(40) NOT NULL DEFAULT 'has_multiserver_paging',

	type_6		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '13',
	line_6		tinyint(2) NOT NULL DEFAULT '1',
	value_6		varchar(99) NOT NULL DEFAULT '##0911',
	label_6		varchar(30) NOT NULL DEFAULT 'Multi-Site      Emerg-All-Call',
	cos_6		varchar(40) NOT NULL DEFAULT 'has_multiserver_paging',

	type_7		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '13',
	line_7		tinyint(2) NOT NULL DEFAULT '1',
	value_7		varchar(99) NOT NULL DEFAULT '#0',
	label_7		varchar(30) NOT NULL DEFAULT 'All-Call',
	cos_7		varchar(40) NOT NULL DEFAULT 'has_all_call_page',

	type_8		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '13',
	line_8		tinyint(2) NOT NULL DEFAULT '1',
	value_8		varchar(99) NOT NULL DEFAULT '#0911',
	label_8		varchar(30) NOT NULL DEFAULT 'Emergency   All-Call',
	cos_8		varchar(40) NOT NULL DEFAULT 'has_emergency_all_call',

	type_9		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '27',
	line_9		tinyint(2) NOT NULL DEFAULT '1',
	value_9		varchar(99) NOT NULL DEFAULT 'tftp://$server_ipaddr/Announcements.xml',
	label_9		varchar(30) NOT NULL DEFAULT 'Announce',
	cos_9		varchar(40) NOT NULL DEFAULT 'has_all_call_page|has_zone_paging',

	type_10		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '27',
	line_10		tinyint(2) NOT NULL DEFAULT '1',
	value_10	varchar(99) NOT NULL DEFAULT 'tftp://$server_ipaddr/progDistList.xml',
	label_10	varchar(30) NOT NULL DEFAULT 'Audio          Distribution',
	cos_10		varchar(40) NOT NULL DEFAULT 'has_program_distribution',

	type_11		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT '27',
	line_11		tinyint(2) NOT NULL DEFAULT '1',
	value_11	varchar(99) NOT NULL DEFAULT 'tftp://$server_ipaddr/schedList-$deviceMac.xml',
	label_11	varchar(30) NOT NULL DEFAULT 'Schedules',
	cos_11		varchar(40) NOT NULL DEFAULT 'schools_sites',

	type_12		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_12		tinyint(2) NOT NULL DEFAULT '1',
	value_12	varchar(99) NOT NULL DEFAULT '',
	label_12	varchar(30) NOT NULL DEFAULT '',
	cos_12		varchar(40) NOT NULL DEFAULT '',

	type_13		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_13		tinyint(2) NOT NULL DEFAULT '1',
	value_13	varchar(99) NOT NULL DEFAULT '',
	label_13	varchar(30) NOT NULL DEFAULT '',
	cos_13		varchar(40) NOT NULL DEFAULT '',

	type_14		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_14		tinyint(2) NOT NULL DEFAULT '1',
	value_14	varchar(99) NOT NULL DEFAULT '',
	label_14	varchar(30) NOT NULL DEFAULT '',
	cos_14		varchar(40) NOT NULL DEFAULT '',

	type_15		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_15		tinyint(2) NOT NULL DEFAULT '1',
	value_15	varchar(99) NOT NULL DEFAULT '',
	label_15	varchar(30) NOT NULL DEFAULT '',
	cos_15		varchar(40) NOT NULL DEFAULT '',

	type_16		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_16		tinyint(2) NOT NULL DEFAULT '1',
	value_16	varchar(99) NOT NULL DEFAULT '',
	label_16	varchar(30) NOT NULL DEFAULT '',
	cos_16		varchar(40) NOT NULL DEFAULT '',

	type_17		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_17		tinyint(2) NOT NULL DEFAULT '1',
	value_17	varchar(99) NOT NULL DEFAULT '',
	label_17	varchar(30) NOT NULL DEFAULT '',
	cos_17		varchar(40) NOT NULL DEFAULT '',

	type_18		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_18		tinyint(2) NOT NULL DEFAULT '1',
	value_18	varchar(99) NOT NULL DEFAULT '',
	label_18	varchar(30) NOT NULL DEFAULT '',
	cos_18		varchar(40) NOT NULL DEFAULT '',

	type_19		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_19		tinyint(2) NOT NULL DEFAULT '1',
	value_19	varchar(99) NOT NULL DEFAULT '',
	label_19	varchar(30) NOT NULL DEFAULT '',
	cos_19		varchar(40) NOT NULL DEFAULT '',

	type_20		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_20		tinyint(2) NOT NULL DEFAULT '1',
	value_20	varchar(99) NOT NULL DEFAULT '',
	label_20	varchar(30) NOT NULL DEFAULT '',
	cos_20		varchar(40) NOT NULL DEFAULT '',

	type_21		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_21		tinyint(2) NOT NULL DEFAULT '1',
	value_21	varchar(99) NOT NULL DEFAULT '',
	label_21	varchar(30) NOT NULL DEFAULT '',
	cos_21		varchar(40) NOT NULL DEFAULT '',

	type_22		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_22		tinyint(2) NOT NULL DEFAULT '1',
	value_22	varchar(99) NOT NULL DEFAULT '',
	label_22	varchar(30) NOT NULL DEFAULT '',
	cos_22		varchar(40) NOT NULL DEFAULT '',

	type_23		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_23		tinyint(2) NOT NULL DEFAULT '1',
	value_23	varchar(99) NOT NULL DEFAULT '',
	label_23	varchar(30) NOT NULL DEFAULT '',
	cos_23		varchar(40) NOT NULL DEFAULT '',

	type_24		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_24		tinyint(2) NOT NULL DEFAULT '1',
	value_24	varchar(99) NOT NULL DEFAULT '',
	label_24	varchar(30) NOT NULL DEFAULT '',
	cos_24		varchar(40) NOT NULL DEFAULT '',

	type_25		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_25		tinyint(2) NOT NULL DEFAULT '1',
	value_25	varchar(99) NOT NULL DEFAULT '',
	label_25	varchar(30) NOT NULL DEFAULT '',
	cos_25		varchar(40) NOT NULL DEFAULT '',

	type_26		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_26		tinyint(2) NOT NULL DEFAULT '1',
	value_26	varchar(99) NOT NULL DEFAULT '',
	label_26	varchar(30) NOT NULL DEFAULT '',
	cos_26		varchar(40) NOT NULL DEFAULT '',

	type_27		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_27		tinyint(2) NOT NULL DEFAULT '1',
	value_27	varchar(99) NOT NULL DEFAULT '',
	label_27	varchar(30) NOT NULL DEFAULT '',
	cos_27		varchar(40) NOT NULL DEFAULT '',

	type_28		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_28		tinyint(2) NOT NULL DEFAULT '1',
	value_28	varchar(99) NOT NULL DEFAULT '',
	label_28	varchar(30) NOT NULL DEFAULT '',
	cos_28		varchar(40) NOT NULL DEFAULT '',

	type_29		enum ('Empty','13','27','Reserved','Zone') NOT NULL DEFAULT 'Zone',
	line_29		tinyint(2) NOT NULL DEFAULT '1',
	value_29	varchar(99) NOT NULL DEFAULT '',
	label_29	varchar(30) NOT NULL DEFAULT '',
	cos_29		varchar(40) NOT NULL DEFAULT '',

PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
